@@ -3,11 +3,12 @@ from .simple_es import Simple_ES
 from .cma_es import CMA_ES
 from .differential_es import Differential_ES
 from .pso_es import PSO_ES
-from .open_nes import Open_NES
-from .pepg_es import PEPG_ES
+from .open_es import Open_ES
+from .pgpe_es import PGPE_ES
 from .pbt_es import PBT_ES
 from .persistent_es import Persistent_ES
 from .xnes import xNES
+from .ars import Augmented_RS
 
 
 __all__ = [
@@ -16,9 +17,10 @@ __all__ = [
     "CMA_ES",
     "Differential_ES",
     "PSO_ES",
-    "Open_NES",
-    "PEPG_ES",
+    "Open_ES",
+    "PGPE_ES",
     "PBT_ES",
     "Persistent_ES",
     "xNES",
+    "Augmented_RS",
 ]
